function [s, nx, ny] = rys(varargin),

% RAYS provide a rays class.
%
% RAYS(<source position>, <target posn>). Generate rays for 
% all combinations source and target positions. 
%
% 
%
% rays('aim',source,phi,theta)
% rays(source, slope)
% obj = rays() % empty rays structure  
% obj = rays('rays',source, target, dx, nrays) % grid of  
% obj = rays(source, target, type) 
% obj = rays(source, target, type) 
%

% 24/11/04 added OPL field

% disp('making rays');

nx = [];
ny = [];

s.angle = [];

if nargin == 0
   
    % return a basic empty ray object 
    s.posn      = [];
    s.slope     = [];
    s.OPL       = [];
    s.index     = [];
    
elseif nargin == 2,
    
    % simple position and ray slope defined
    s.posn  = varargin{1};
    s.slope = varargin{2};
    s.OPL   = zeros([ size(s.posn,1) 1 ]);
    s.index  = 1;
    
elseif nargin == 3,
    
     if (ischar(varargin{1})),
        
         switch(varargin{1})
    
            case { 'target' }
               
                x = getray(varargin{2},varargin{3},'source');
                s.posn  = x(:,1:3);
                s.slope = x(:,4:6);
                s.OPL   = zeros([ size(s.posn,1) 1 ]);
                s.index  = 1;
                    
            otherwise
          
                error('otherwise encountered.');
                
         end 
    
     else 
        % all ray parts defined 
        s.posn  = varargin{1};
        s.slope = varargin{2};
        s.OPL   = varargin{3};
        s.index = 1;    
    end 
    
elseif nargin == 4,
    
     % disp('aimed option');
    
     if (ischar(varargin{1})),
    
        % 'aim',source, posn, phi, theta 
         
        switch(varargin{1})
        
            case { 'FANY' }
                
                nd      = varargin{4};
                ang     = varargin{3};
                posn    = varargin{2};
                posn    = [ 0 0 posn ];
                
                theta   = linspace(ang(1),ang(2),nd)';
                s.posn  = posn(ones([ length(theta) 1]),:);
                s.slope = [ 0*theta sin(theta) cos(theta) ]; 
    
            case { 'aim' }
                
                phi     = varargin{3};
                theta   = varargin{4};
            
                s.angle = [ phi theta ];
                s.posn  = varargin{2};
                
                n = size(s.angle,1);
                if ((size(s.posn,1) == 1)&(n > 1)),
                    s.posn = s.posn(ones([ n 1 ]),:);
                end
                
                % size(s.posn)
                
                s.slope = [ cos(theta).*sin(phi) sin(theta) cos(theta).*cos(phi) ]; 
                
                % size(s.slope)
                
                
            case { 'p-grid' }
                
                % ---------------------------------------------
                % rays('p-grid',[ -pi pi -pi pi],[0 0 -6000],8)
                % ---------------------------------------------
                
                nd      = varargin{4};
                ang     = varargin{2};
                posn    = varargin{3};
                phi     = linspace(ang(1), ang(2), nd);
                theta   = linspace(ang(3), ang(4), nd);
                
                [nx, ny] = meshgrid(1:length(phi),1:length(theta));
                [phi, theta] = meshgrid(phi,theta);
                
                phi = phi(:); theta = theta(:); 
                nx  = nx(:);  ny = ny(:);
                
                s.angle  = [ phi(:) theta(:) ];
                s.posn   = posn(ones([ size(phi,1) 1 ]),:); 
                s.slope  = [ cos(theta).*sin(phi) sin(theta) cos(theta).*cos(phi) ]; 
    
                
            otherwise, 
                
                
        end 
    
        s.OPL   = zeros(size(s.posn,1),1);
        s.index = 1;    
            
     else 
         
        % all ray parts defined 
        s.posn  = varargin{1};
        s.slope = varargin{2};
        s.OPL   = varargin{3};
        s.index = varargin(4);
    end
        
        
elseif nargin == 5,
    
    if (ischar(varargin{1}))
        if (strcmp(varargin{1},'rays'))
    
            source  = varargin{2};
            target  = varargin{3};
            dx      = varargin{4};
            nrays   = varargin{5};
                        
            [s.posn, s.slope]   = m_gridsource(target, source, dx, nrays);
            
            s.OPL               = zeros(size(s.posn,1),1);
            s.index             = 1;        
            
        end 
    end 
    
end

s = class(s, 'rays');

return

% M_GRIDSOURCE internal function
%
%

function [x,s] = m_gridsource(T,S,boxside,nrays),

  % generate PSFs
  grid.type = 'square';
  tgrid = getgrid(nrays, boxside, grid, T);
  tray  = getray(S, tgrid, 'source');
  
  x = tray(:,1:3);
  s = tray(:,4:6);

return
