function [Z, M, I1] = trayelp1(InInfoA, InInfoB, InInfoC, I1)

% TRAYELP1 ellipse intersection re-coded to try and get some
% speed out of it.  rays that dont hit the extent are removed
% altogether
% 
%  InInfoA  = posn
%  InInfoB  = rays  
%  InInfoC  = [a.b.c]
%  I1       = indexes 



X0 	= InInfoA;
M 	= InInfoB;
A 	= InInfoC(4:6);  A = (1./(A.^2))';
C 	= InInfoC(1:3);  C(3) = C(3) + InInfoC(6);
dr	= InInfoC(7);


nlen    = size(X0,1);
P0      = InInfoC(1:3);
P0      = P0(ones([ nlen 1]),:);

% find intersection
DXC  = (X0 - C(ones([nlen 1]),:));


a1 = (M.*M)*A;
b1 = 2*(M.*DXC)*A;
c1 = (DXC.*DXC)*A - 1;

disc   = b1.^2 - 4.*a1.*c1;

if     any(disc<=0),
       
       It     = find(disc>0);   % discard rays that miss the ellipse      
       a1      = a1(It);
       b1      = b1(It);
       disc    = disc(It);
       I1      = I1(It);
       M       = M(It,:);
       X0      = X0(It,:);
       P0      = P0(It,:);                              
end


% no rays succeeded - return
if    isempty(disc)
      Z = [];
      M = [];
      I1 = [];
      return
end


disc   = sqrt(disc);   
l1     = (-b1 + disc)./(2*a1);
l2     = (-b1 - disc)./(2*a1);

L      = [ l1 l2 ];
l1     = l1(:,[1 1 1]);
l2     = l2(:,[1 1 1]);


% only take the root closest to the vertex
P1     = M.*l1 + X0;
P2     = M.*l2 + X0;
N(1,:) = sqrt(sum(((P1-P0).^2)'));
N(2,:) = sqrt(sum(((P2-P0).^2)'));
[ dummy Imin ] = min(N); N = N'; dummy = [];
J = (1:length(Imin))';   Imin = Imin';   
ind  = sub2ind(size(N),J,Imin);
L    = L(ind); L = L(:,[ 1 1 1 ]);


% finally compute the intersect position
Z = M.*L + X0;

   
% discard rays out of radius
DR  = (Z - P0);  
DR  = sqrt(sum((DR(:,1:2).^2)'))';
   
if  any(DR>dr),
    mdisp('rays fall outside of radius');     
    It  = find(DR<dr);
    Z   = Z(It,:);
    I1  = I1(It);
    M   = M(It,:);
end


return
