function [ nPos, j ] = nsect(strFn, nPos, nSlope, nAp, varargin);

% NSECT call the correct functions to do the tracing.  Do the 
% tracing on the canonical version of the surface. 
% 
% [nPos, j] = NSECT(strFn, nPos, nSlope, nAp, ...). Trace the ray with 
% with position nPos and nSlope to the surface defined by strFn.  The 
% rays that fall outside the aperture nAp will be discarded. 
%
% This function assumes the surface centered frame. 
%
   strFn0 = sprintf('trace_%s', strFn);
   nPos0 = nPos; nSlope0 = nSlope;
   [nPos, j] = feval(strFn0, nPos, nSlope, nAp, varargin{:});

   % ray trace check - was intersection consistent? 
   if (~isempty(nPos)), 
        switch(feval(strFn0,'type')),
            case { 'analytic' }
            z0 = feval(strFn, nPos(:,1), nPos(:,2), varargin{:});
            case { 'numeric' }
            z0 = feval(strFn, nPos(:,1), nPos(:,2), varargin{2:end});
            otherwise,
            error('(NSECT) Unknown analytic or numeric.');
        end 
                
        e  = abs(z0-nPos(:,3));
        i  = (e > 1e-6);
        if (any(i)),
            error('(NSECT) It appears an inconsistent ray trace occured.');    
        end     
    end     
   
return
