function [m_nPos, m_j] = trace_pupil(nPos, nSlope, nAp)

% TRACE_PUPIL intersect a origin centered conic surface
% with a ray (nPos, nSlope). 
%
% TRACE_PUPIL(nPos, nSlope, nAp).  Here nPos is the position,
% nSlope is the ray slope, nAp is the aperture. The intersection 
% point is returned as well as an index into the rays that are remaining.
% 
% TRACE_PUPIL('type').  Returns 'analytic' which means that the ray 
% intersections are derived, rather than found by numeric means. 
%
% nSlope is the ray slope, nAp is the aperture. The intersection 
% point is returned as well as an index into the rays that are remaining.
% 

if (nargin == 1),
    if (strcmp(nPos, 'type')),
        m_nPos = 'analytic'; m_j = [];
        return
    end
    error('(TRACE_PUPIL) Error in invocation.');
end

% internal index
j = (1:size(nPos, 1))';  
m_j = []; m_nPos = [];

% no intersection is possible
ndx = (nPos(:,3).*nSlope(:,3) > 0); 
if (any(ndx)),
    if(all(ndx)),
        return
    end
    % remaining
    ndx = ~ndx;
    nPos   = nPos(ndx, :);
    nSlope = nSlope(ndx, :);
    j      = j(ndx,:);
end

% shift to origin
l         = -nPos(:,3)./nSlope(:,3);
nPos(:,1) = nPos(:,1) + nSlope(:,1).*l;
nPos(:,2) = nPos(:,2) + nSlope(:,2).*l;
nPos(:,3) = 0;

% send to surface 
r  = sqrt(nPos(:,1).^2 + nPos(:,2).^2 );
ndx  = (r <= nAp);
if   any(ndx),
     m_j      = j(ndx);
     m_nPos   = nPos(ndx,:);
     m_nSlope = nSlope(ndx,:);
     return
end

% remaining rays are bad.
error('(TRACETO_PUPIL) Error. Rays remain unprocessed.');
return