function [m_nPos, m_j] = trace_rksicam(nPos, nSlope, nAp, etol, varargin)

% TRACE_RKSICAM intersect any ray (nPos, nSlope) surface that 
% has a centered representation using a numeric approach. 
%
% TRACE_RKSICAM(strFn, nPos, nSlope, nAp, ...).  Here nPos is the position,
% nSlope is the ray slope, nAp is the aperture and (CV, CC) are conic 
% arguments. The intersection point is returned as well as an index 
% into the rays that are remaining.
% 
% EXAMPLE 
%
%   CV = 1/7; CC = 0; nAp =4; etol = 1e-9;
%   [nPos, nSlope] = createray([0 0 -10],[0 1 0]); 
%   [nPos, j] = trace_rksicam(nPos, nSlope, nAp, etol, CV, CC);
% 

if (nargin == 1),
    if (strcmp(nPos, 'type')),
        m_nPos = 'numeric'; m_j = [];
        return
    end
    error('(TRACE_RKSICAM) Error in invocation.');
end

[m_nPos, m_j] = trace_general('rksicam', nPos, nSlope, nAp, etol, varargin{:});

return
