function [ y, varargout ] = getPupil(p, nApID, strf),

% GETPUPIL return the Entrance/Exit pupils for the 
% optical system p. 
%
% GETPUPIL(p, nApID). Here p is the optical system and 
% nID is the ID of the aperture stop.  This procedure assumes 
% the aperture stop is the smallest radius of surface.
%
% GETPUPIL(p, strf). Here p is the optical system and 
% strf is { 'exit','entr','both' }.  This invocation uses 
% GETMINAP - essentially chooses the smallest aperture. 
%
% GETPUPIL(p, nApID, strf). The additional string is the exit
% { 'exit' } or entrance { 'entr' }  pupil. This function will 
% return the entrance/exit pupil with respect to the front  
% vertex position (i.e. (0,0,0)).


% return the system matrix 
S  = eye(2);

if (nargin == 1),
    nApID = getMinAp(p);
end 

if (nargin == 2),
   if (isnumeric(nApID)),
    strf = 'both';
   elseif (ischar(nApID)),
    strf  = nApID;
    nApID = getMinAp(p);
   else
    error('(GETPUPIL) Bad invocation.');
   end
end

% minimum aperture 
p     = seek(p, nApID);
nApPr = get(p);
x0    = get(nApPr, 'position');
nAp   = get(nApPr, 'aperture');


switch(strf),
    case { 'entr' }, % entr. pupil  
    p  = seek(p, nApID-1);
    p1 = split(p, 'front');
    q1 = parax(p1);
        
    if (~isfinite(nAp)),
        nAp = 0;
    end
    
    [y, nAp1] = pImg2Obj(q1.S, x0(3)-q1.BVP, nAp);
    y = y + q1.FVP;
    varargout{1} = nAp1;
    return 
 
    case { 'exit' }, % exit pupil 
    p  = seek(p, nApID-1);
    p2 = split(p, 'back');
    q2 = parax(p2);
    p2 = seek(p2,2);
    
    if (~isfinite(nAp)),
        nAp = 0;
    end
    
    [y, nAp2] = pObj2Img(q2.S, x0(3)-q2.FVP, nAp);
    y = y + q2.BVP;
    varargout{1} = nAp2;
    return
    
    case {'both'}
    p  = seek(p, nApID-1);
    p2 = split(p, 'back');
    q2 = parax(p2);
    p2 = seek(p2,2);
    
    if (~isfinite(nAp)),
        nAp = 0;
    end
    
    
    [y, nAp2] = pObj2Img(q2.S, x0(3)-q2.FVP, nAp);
    varargout{1} = { y + q2.BVP };
    varargout{3} = nAp2;    
    
    p  = seek(p, nApID-1);
    p1 = split(p, 'front');
    q1 = parax(p1);
    [y, nAp1] = pImg2Obj(q1.S, x0(3)-q1.BVP, nAp);
    y = y + q1.FVP;
    varargout{2} = nAp1;
    
    otherwise,
        error('(PUPIL) Return the pupil.');
end 

return