function [nR, nCZ, nC, nOPLZ, nOPL ] = getRefSph(p0, s0, nZ),

% GETREFSPH Return reference sphere details 
% 
% [ nR, nCZ, nC, nOPLZ ] = GETREFSPH(p, s0, nZ). Trace an axial ray through the lens  
% prescription. nZ is the apex of the reference plane, nR is the radius of 
% the reference sphere, nC is the intersection of the reference sphere with
% the reference plane, and nOPLZ is OPL at the image plane. 
%
% EXAMPLE 
%
% [nR, nCZ, nC, nOPLZ, nOPL ] = getRefSph(p0, s0, nZ);
%   
%
    
    nS = [ 0 0 s0 ];
    
    % chief ray (output plane)
    rp      = ray(nS, [0 0 1]);   % flat with sources
    rp      = trace(rp, p0);    
    nC      = get(rp,'position');   % image plane intersection 
    nCSlope = get(rp,'slope');
    nOPL    = get(rp,'OPL');
    
    % chief. ray (exit pupil) 
    rp    = trans(rp, nZ);             
    nOPLZ = get(rp,'OPL');
    nCZ   = get(rp,'position');
    nR    = norm(nC - nCZ);  % reference sphere                 

return 