function n = herzberger(x, n1, nF, nc, n2),

% HERZBERGER. Implement the herzberger formula 
%
% HERZBERGER(x, n**, nF, nc, n*). Here x is the wavelength
% in micrometers, (n**, nF, nc, n*) are the coefficients as
% described below. 
% 
% HERZBERGER(x, [n**, nF, nc, n*]). Here x is the wavelength
% in micrometers, (n**, nF, nc, n*) is a vector of the same
% coefficients.
%
% The Herzberger formula is given by 
%
%  n(l) = a1(l)(n**) + a2(x)(nF) + a3(x)(ne) + a4(x)(n*)
%
% where 
% 
%   n** = n(x = 0.365 micron)
%   nF  = n(x = 0.4861 micron)
%   nc  = n(x = 0.6563 micron)
%   n*  = n(x = 1.014 micron)
%
% Medium    n**     nF      nc      n* 
%
% Cornea    1.3975  1.3807  1.37405 1.3668
% Aqueous   1.3593  1.3422  1.3354  1.3278
% Lens      1.4492  1.42625 1.4175  1.4097
% vitreous  1.3565  1.3407  1.3341  1.3273
%
% using details presented in :
% 
% R. Navarro, J. Santamaria, and J. Bescos, "Accommodation-dependent model of the 
% human eye with aspherics," J. Opt. Soc. Am. A 2(8), 1273-1281 (1985)
% 

error('(HERZBERGER) implementation ocrrect. The coefficients dont seem to work.');

if (nargin == 2),
    nF = n1(2);
    nc = n1(3);
    n2 = n1(4);
    n1 = n1(1);
end 

x02 = 0.028; % \mum^2 
dx  = (x.^2-x02);

a1 = 0.66147196 - 0.040352796*x.^2 - 0.2804679/dx + 0.03385979/dx.^2;
a2 = -4.20146383 + 2.73508956*x.^2 + 1.50543784/dx - 0.11593235/dx.^2;
a3 = 6.29834237 - 4.69409935*x.^2 - 1.5750865/dx + 0.10293038/dx.^2;
a4 = 1.75835059 + 2.3625379*x.^2 + 0.35011657/dx - 0.02085782/dx.^2;
n = a1*n1 + a2*nF + a3*nc + a4*n2;

