function X = eyemodel_navarro(npupil),

% Navarro Eye 
% 
% (1) - Accomodation-dependent model of the human eye with aspherics 
% Navarro R, Santamaria J, Bescos J. Vol. 2, No.8/August 1985/J. Opt. Soc. Am. A p 1273
% 
% (2) - nb: error that eye - correction in Escudero-Sanz I, Navarro R, JOSA 16(8) p1881
%
% X = new_NavarroEye(npupil),
% 
% where
%       npupil = pupil diameter (mm)
%

if (nargin == 0)
    npupil = 2; % mm
end

  X   = optics;
  Y   = primitive('index',1,'air'); 
  X   = append(X,Y);
  Y   = primitive('quadric',[0 0 0],[0 0 0],5,'convex','on',[7.72 -0.26],'Anterior Cornea');
  X   = append(X,Y);  
  Y   = primitive('index',1.376,'Cornea');   % used to be 1.367
  X   = append(X,Y);
  % Y   = primitive('quadric',[0 0 0.55],[0 0 0],6,'convex','on',[6.5 0],'Posterior Cornea');
  Y   = primitive('sphere',[0 0 0.55],[0 0 0],5,'on',6.5,'Posterior Cornea');
  X   = append(X,Y);
  Y   = primitive('index',1.3374,'Aqueous');
  X   = append(X,Y);
  Y   = primitive('pupil',[0 0 3.6],[0 0 0],npupil/2,'on','Pupil');
  X   = append(X,Y);
  Y   = primitive('index',1.3374,'Aqueous');
  X   = append(X,Y);
  Y   = primitive('quadric',[0 0 3.6],[0 0 0],5,'convex','on',[10.2 -3.1316],'Anterior Lens');
  X   = append(X,Y);
  Y   = primitive('index',1.42,'Lens');
  X   = append(X,Y);
  Y   = primitive('quadric',[0 0 7.6],[0 0 0],5,'concave','on',[-6 -1],'Posterior Lens');
  X   = append(X,Y);
  Y   = primitive('index',1.336,'Vitreous');
  X   = append(X,Y);
  Y   = primitive('image',[0 0 24],[0 0 0],50,'on','Retina');
  X   = append(X,Y);
  % Y   = primitive('index',1.336,'Dummy');
  % X   = append(X,Y);

  X = rewind(X); 

return


%
% HERZBERGER doesnt work 
%

function y = refractive(lambda),

    lambda = 0.365;
    
    % see Table 2 of (1) [ 0.365, 0.4861, 0.6563, 1.014 ] micron 
    % rows are cornea, aqueous, lens, vitreous
    n   = [ 1.3975  1.3807   1.37405   1.3668 ; 
            1.3593  1.3422   1.3354    1.3278 ;
            1.4492  1.42625  1.4175    1.4097 ;
            1.3565  1.3407   1.3341    1.3273 ];

   a   = [ 0.66147196 -0.040352796 -0.2804679 0.03385979 ;
      -4.20146383 2.73508956 1.50543784 -0.11593235 ;
      6.29834237 -4.69409935 -1.5750865 0.10293038 ;
      1.75835059 2.36253794 0.35011657 -0.02085782 ];
  
    % determine the coefficients
    l0    = 0.028 ; % micron^2 
    lda   = [ 0.365 0.4861 0.6563 1.1014 ].^2;
    lda   = [ 1 1 1 1 ; lda ; (1./(lda - l0)) ; (1./(lda - l0)).^2 ]; 
 
    a     = a - eye(4);
    y     = a*lda
    
    rref([ y a(:,1)*0 ])
    
return