function [x, y] = pObj2Img(S, x, y);

% POBJ2IMG Paraxial Object point to Image Space  
%
% POBJ2IMG(S, x, y). Determine the image space 
% conjugate to the object point (x,y).  That point (x,y) 
% is given w.r.t. the front vertex plane.  The output 
% points will be w.r.t. to the back vertex plane 
% typical input object will have x < 0 two arbitrary rays.
%
% POBJ2IMG(S, x).  A default object height of y = 0 is used in this 
% case.

if (nargin == 2),
    y = 0;
end

% use two rays 
y  = [ 0 -tan(pi/4) ; y y ];
T  = [ 1 0 ; -x 1 ];        % transfer rays to FVP
y  = S*T*y;                 % put through system
x  = -(y(2,1)-y(2,2))/(y(1,1)-y(1,2));
y  = y(1,1)*x + y(2,1);
return
